# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vantage.configuration import Configuration


class Costs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'object',
        'total': 'str',
        'currency': 'str',
        'costs': 'list[Cost]'
    }

    attribute_map = {
        'links': 'links',
        'total': 'total',
        'currency': 'currency',
        'costs': 'costs'
    }

    def __init__(self, links=None, total=None, currency=None, costs=None, _configuration=None):  # noqa: E501
        """Costs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._links = None
        self._total = None
        self._currency = None
        self._costs = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if total is not None:
            self.total = total
        if currency is not None:
            self.currency = currency
        if costs is not None:
            self.costs = costs

    @property
    def links(self):
        """Gets the links of this Costs.  # noqa: E501


        :return: The links of this Costs.  # noqa: E501
        :rtype: object
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Costs.


        :param links: The links of this Costs.  # noqa: E501
        :type: object
        """

        self._links = links

    @property
    def total(self):
        """Gets the total of this Costs.  # noqa: E501

        The sum of all amounts of costs for the entire report for the requested period.  # noqa: E501

        :return: The total of this Costs.  # noqa: E501
        :rtype: str
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Costs.

        The sum of all amounts of costs for the entire report for the requested period.  # noqa: E501

        :param total: The total of this Costs.  # noqa: E501
        :type: str
        """

        self._total = total

    @property
    def currency(self):
        """Gets the currency of this Costs.  # noqa: E501

        The currency both the total and cost amount values are represented in. e.g. USD  # noqa: E501

        :return: The currency of this Costs.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Costs.

        The currency both the total and cost amount values are represented in. e.g. USD  # noqa: E501

        :param currency: The currency of this Costs.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def costs(self):
        """Gets the costs of this Costs.  # noqa: E501


        :return: The costs of this Costs.  # noqa: E501
        :rtype: list[Cost]
        """
        return self._costs

    @costs.setter
    def costs(self, costs):
        """Sets the costs of this Costs.


        :param costs: The costs of this Costs.  # noqa: E501
        :type: list[Cost]
        """

        self._costs = costs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Costs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Costs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Costs):
            return True

        return self.to_dict() != other.to_dict()
